==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/gl.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'gl', {
	button: {
		title: 'Propiedades do botón',
		text: 'Texto (Valor)',
		type: 'Tipo',
		typeBtn: 'Botón',
		typeSbm: 'Enviar',
		typeRst: 'Restabelever'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propiedades da caixa de selección',
		radioTitle: 'Propiedades do botón de opción',
		value: 'Valor',
		selected: 'Seleccionado'
	},
	form: {
		title: 'Propiedades do formulario',
		menu: 'Propiedades do formulario',
		action: 'Acción',
		method: 'Método',
		encoding: 'Codificación'
	},
	hidden: {
		title: 'Propiedades do campo agochado',
		name: 'Nome',
		value: 'Valor'
	},
	select: {
		title: 'Propiedades do campo de selección',
		selectInfo: 'Información',
		opAvail: 'Opcións dispoñíbeis',
		value: 'Valor',
		size: 'Tamaño',
		lines: 'liñas',
		chkMulti: 'Permitir múltiplas seleccións',
		opText: 'Texto',
		opValue: 'Valor',
		btnAdd: 'Engadir',
		btnModify: 'Modificar',
		btnUp: 'Subir',
		btnDown: 'Baixar',
		btnSetValue: 'Estabelecer como valor seleccionado',
		btnDelete: 'Eliminar'
	},
	textarea: {
		title: 'Propiedades da área de texto',
		cols: 'Columnas',
		rows: 'Filas'
	},
	textfield: {
		title: 'Propiedades do campo de texto',
		name: 'Nome',
		value: 'Valor',
		charWidth: 'Largo do carácter',
		maxChars: 'Núm. máximo de caracteres',
		type: 'Tipo',
		typeText: 'Texto',
		typePass: 'Contrasinal',
		typeEmail: 'Correo',
		typeSearch: 'Buscar',
		typeTel: 'Número de teléfono',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/gl.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'gl', {
	button: {
		title: 'Propiedades do botón',
		text: 'Texto (Valor)',
		type: 'Tipo',
		typeBtn: 'Botón',
		typeSbm: 'Enviar',
		typeRst: 'Restabelever'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Propiedades da caixa de selección',
		radioTitle: 'Propiedades do botón de opción',
		value: 'Valor',
		selected: 'Seleccionado',
		required: 'Requirido'
	},
	form: {
		title: 'Propiedades do formulario',
		menu: 'Propiedades do formulario',
		action: 'Acción',
		method: 'Método',
		encoding: 'Codificación'
	},
	hidden: {
		title: 'Propiedades do campo agochado',
		name: 'Nome',
		value: 'Valor'
	},
	select: {
		title: 'Propiedades do campo de selección',
		selectInfo: 'Información',
		opAvail: 'Opcións dispoñíbeis',
		value: 'Valor',
		size: 'Tamaño',
		lines: 'liñas',
		chkMulti: 'Permitir múltiplas seleccións',
		required: 'Requirido',
		opText: 'Texto',
		opValue: 'Valor',
		btnAdd: 'Engadir',
		btnModify: 'Modificar',
		btnUp: 'Subir',
		btnDown: 'Baixar',
		btnSetValue: 'Estabelecer como valor seleccionado',
		btnDelete: 'Eliminar'
	},
	textarea: {
		title: 'Propiedades da área de texto',
		cols: 'Columnas',
		rows: 'Filas'
	},
	textfield: {
		title: 'Propiedades do campo de texto',
		name: 'Nome',
		value: 'Valor',
		charWidth: 'Largo do carácter',
		maxChars: 'Núm. máximo de caracteres',
		required: 'Requirido',
		type: 'Tipo',
		typeText: 'Texto',
		typePass: 'Contrasinal',
		typeEmail: 'Correo',
		typeSearch: 'Buscar',
		typeTel: 'Número de teléfono',
		typeUrl: 'URL'
	}
} );
